package com.ruoyi.system.controller;

import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PutMapping;
import com.ruoyi.common.security.utils.SecurityUtils;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.core.web.domain.AjaxResult;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import javax.servlet.http.HttpServletResponse;
import org.springframework.web.bind.annotation.GetMapping;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import java.util.List;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.system.domain.SysPost;
import org.springframework.beans.factory.annotation.Autowired;
import com.ruoyi.system.service.ISysPostService;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.core.web.controller.BaseController;

@RestController
@RequestMapping({ "/post" })
public class SysPostController extends BaseController
{
    @Autowired
    private ISysPostService postService;
    
    @RequiresPermissions({ "system:post:list" })
    @GetMapping({ "/list" })
    public TableDataInfo list(final SysPost post) {
        this.startPage();
        final List<SysPost> list = this.postService.selectPostList(post);
        return this.getDataTable((List)list);
    }
    
    @Log(title = "岗位管理", businessType = BusinessType.EXPORT)
    @RequiresPermissions({ "system:post:export" })
    @PostMapping({ "/export" })
    public void export(final HttpServletResponse response, final SysPost post) {
        final List<SysPost> list = this.postService.selectPostList(post);
        final ExcelUtil<SysPost> util = (ExcelUtil<SysPost>)new ExcelUtil((Class)SysPost.class);
        util.exportExcel(response, (List)list, "岗位数据");
    }
    
    @RequiresPermissions({ "system:post:query" })
    @GetMapping({ "/{postId}" })
    public AjaxResult getInfo(@PathVariable final Long postId) {
        return this.success((Object)this.postService.selectPostById(postId));
    }
    
    @RequiresPermissions({ "system:post:add" })
    @Log(title = "岗位管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody final SysPost post) {
        if (!this.postService.checkPostNameUnique(post)) {
            return this.error("新增岗位'" + post.getPostName() + "'失败，岗位名称已存在");
        }
        if (!this.postService.checkPostCodeUnique(post)) {
            return this.error("新增岗位'" + post.getPostName() + "'失败，岗位编码已存在");
        }
        post.setCreateBy(SecurityUtils.getUsername());
        return this.toAjax(this.postService.insertPost(post));
    }
    
    @RequiresPermissions({ "system:post:edit" })
    @Log(title = "岗位管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody final SysPost post) {
        if (!this.postService.checkPostNameUnique(post)) {
            return this.error("修改岗位'" + post.getPostName() + "'失败，岗位名称已存在");
        }
        if (!this.postService.checkPostCodeUnique(post)) {
            return this.error("修改岗位'" + post.getPostName() + "'失败，岗位编码已存在");
        }
        post.setUpdateBy(SecurityUtils.getUsername());
        return this.toAjax(this.postService.updatePost(post));
    }
    
    @RequiresPermissions({ "system:post:remove" })
    @Log(title = "岗位管理", businessType = BusinessType.DELETE)
    @DeleteMapping({ "/{postIds}" })
    public AjaxResult remove(@PathVariable final Long[] postIds) {
        return this.toAjax(this.postService.deletePostByIds(postIds));
    }
    
    @GetMapping({ "/optionselect" })
    public AjaxResult optionselect() {
        final List<SysPost> posts = this.postService.selectPostAll();
        return this.success((Object)posts);
    }
}
